@@ -338,7 +338,10 @@ class PreferencesManager(component.Component):
     def _on_set_utpex(self, key, value):
         log.debug("utpex value set to %s", value)
         if value:
-            self.session.add_extension(lt.create_ut_pex_plugin)
+            # Note: All libtorrent python bindings to set plugins/extensions need to be disabled
+            # due to  GIL issue. https://code.google.com/p/libtorrent/issues/detail?id=369
+            #self.session.add_extension(lt.create_ut_pex_plugin)
+            pass
 
     def _on_set_encryption(self, key, value):
         log.debug("encryption value %s set to %s..", key, value)
@@ -468,15 +471,14 @@ class PreferencesManager(component.Component):
 
     def _on_set_proxies(self, key, value):
         for k, v in value.items():
-            if v["type"]:
-                proxy_settings = lt.proxy_settings()
-                proxy_settings.type = lt.proxy_type(v["type"])
-                proxy_settings.username = str(v["username"])
-                proxy_settings.password = str(v["password"])
-                proxy_settings.hostname = str(v["hostname"])
-                proxy_settings.port = v["port"]
-                log.debug("setting %s proxy settings", k)
-                getattr(self.session, "set_%s_proxy" % k)(proxy_settings)
+            proxy_settings = lt.proxy_settings()
+            proxy_settings.type = lt.proxy_type(v["type"])
+            proxy_settings.username = str(v["username"])
+            proxy_settings.password = str(v["password"])
+            proxy_settings.hostname = str(v["hostname"])
+            proxy_settings.port = v["port"]
+            log.debug("setting %s proxy settings", k)
+            getattr(self.session, "set_%s_proxy" % k)(proxy_settings)
 
     def _on_rate_limit_ip_overhead(self, key, value):
         log.debug("%s: %s", key, value)
