@@ -239,7 +239,7 @@ class GtkUiNotifications(CustomNotifications):
         log.debug("Handler for TorrentFinishedEvent GTKUI called. "
                   "Got Torrent Status")
         title = _("Finished Torrent")
-        message = _("The torrent \"%(name)s\" including %(num_files)i "
+        message = _("The torrent \"%(name)s\" including %(num_files)i file(s) "
                     "has finished downloading.") % torrent_status
         return title, message
 
@@ -284,7 +284,7 @@ class GtkUI(GtkPluginBase, GtkUiNotifications):
         if parent:
             parent.remove(self.prefs)
         index = prefs.notebook.append_page(self.prefs)
-        prefs.liststore.append([index, "Notifications"])
+        prefs.liststore.append([index, _("Notifications")])
 
         component.get("PluginManager").register_hook("on_apply_prefs",
                                                      self.on_apply_prefs)
@@ -317,7 +317,7 @@ class GtkUI(GtkPluginBase, GtkUiNotifications):
 
     def disable(self):
         GtkUiNotifications.disable(self)
-        component.get("Preferences").remove_page("Notifications")
+        component.get("Preferences").remove_page(_("Notifications"))
         component.get("PluginManager").deregister_hook("on_apply_prefs",
                                                        self.on_apply_prefs)
         component.get("PluginManager").deregister_hook("on_show_prefs",
