@@ -109,6 +109,11 @@ class SystemTray(component.Component):
             log.debug("Enabling the Application Indicator..")
             self.indicator = appindicator.Indicator (
                 "deluge", "deluge", appindicator.CATEGORY_APPLICATION_STATUS)
+            try:
+                self.indicator.set_property ("title", _("Deluge"))
+            except TypeError:
+                # Catch 'title' property error for previous appindicator versions
+                pass
             # Pass the menu to the Application Indicator
             self.indicator.set_menu(self.tray_menu)
 
@@ -138,10 +143,9 @@ class SystemTray(component.Component):
             self.tray.connect("activate", self.on_tray_clicked)
             self.tray.connect("popup-menu", self.on_tray_popup)
 
-            # For some reason these icons do not display in appindicator
-            self.tray_glade.get_widget("download-limit-image").set_from_file(
+        self.tray_glade.get_widget("download-limit-image").set_from_file(
                 deluge.common.get_pixmap("downloading16.png"))
-            self.tray_glade.get_widget("upload-limit-image").set_from_file(
+        self.tray_glade.get_widget("upload-limit-image").set_from_file(
                 deluge.common.get_pixmap("seeding16.png"))
 
         client.register_event_handler("ConfigValueChangedEvent", self.config_value_changed)
@@ -157,21 +161,14 @@ class SystemTray(component.Component):
         if self.config["enable_system_tray"]:
 
             if self.config["classic_mode"]:
-                self.hide_widget_list.remove("menuitem_quitdaemon")
-                self.hide_widget_list.remove("separatormenuitem4")
+                try:
+                    self.hide_widget_list.remove("menuitem_quitdaemon")
+                    self.hide_widget_list.remove("separatormenuitem4")
+                except ValueError:
+                    pass
                 self.tray_glade.get_widget("menuitem_quitdaemon").hide()
                 self.tray_glade.get_widget("separatormenuitem4").hide()
 
-            # These do not work with appindicator currently and can crash Deluge.
-            # Related to Launchpad bug #608219
-            if appindicator and self.config["enable_appindicator"]:
-                self.hide_widget_list.remove("menuitem_download_limit")
-                self.hide_widget_list.remove("menuitem_upload_limit")
-                self.hide_widget_list.remove("separatormenuitem3")
-                self.tray_glade.get_widget("menuitem_download_limit").hide()
-                self.tray_glade.get_widget("menuitem_upload_limit").hide()
-                self.tray_glade.get_widget("separatormenuitem3").hide()
-
             # Show widgets in the hide list because we've connected to a host
             for widget in self.hide_widget_list:
                 self.tray_glade.get_widget(widget).show()
@@ -190,7 +187,7 @@ class SystemTray(component.Component):
         self.__start()
 
     def stop(self):
-        if self.config["enable_system_tray"]:
+        if self.config["enable_system_tray"] and not self.config["enable_appindicator"]:
             try:
                 # Hide widgets in hide list because we're not connected to a host
                 for widget in self.hide_widget_list:
@@ -198,7 +195,7 @@ class SystemTray(component.Component):
             except Exception, e:
                 log.debug("Unable to hide system tray menu widgets: %s", e)
 
-            self.tray.set_tooltip(_("Deluge\nNot Connected.."))
+            self.tray.set_tooltip(_("Deluge") + "\n" + _("Not Connected..."))
 
     def shutdown(self):
         if self.config["enable_system_tray"]:
@@ -266,16 +263,15 @@ class SystemTray(component.Component):
     def build_tray_bwsetsubmenu(self):
         # Create the Download speed list sub-menu
         submenu_bwdownset = common.build_menu_radio_list(
-                self.config["tray_download_speed_list"], self.tray_setbwdown,
+                self.config["tray_download_speed_list"], self.on_tray_setbwdown,
                 self.max_download_speed,
                      _("KiB/s"), show_notset=True, show_other=True)
 
         # Create the Upload speed list sub-menu
         submenu_bwupset = common.build_menu_radio_list(
-                self.config["tray_upload_speed_list"], self.tray_setbwup,
+                self.config["tray_upload_speed_list"], self.on_tray_setbwup,
                 self.max_upload_speed,
                 _("KiB/s"), show_notset=True, show_other=True)
-
         # Add the sub-menus to the tray menu
         self.tray_glade.get_widget("menuitem_download_limit").set_submenu(
             submenu_bwdownset)
@@ -286,10 +282,6 @@ class SystemTray(component.Component):
         submenu_bwdownset.show_all()
         submenu_bwupset.show_all()
 
-        # Re-set the menu to partly work around Launchpad bug #608219
-        if appindicator and self.config["enable_appindicator"]:
-            self.indicator.set_menu(self.tray_menu)
-
     def disable(self,invert_app_ind_conf=False):
         """Disables the system tray icon or appindicator."""
         try:
@@ -360,6 +352,7 @@ class SystemTray(component.Component):
         popup_function = gtk.status_icon_position_menu
         if deluge.common.windows_check():
             popup_function = None
+            button = 0
         self.tray_menu.popup(None, None, popup_function,
             button, activate_time, status_icon)
 
@@ -399,10 +392,22 @@ class SystemTray(component.Component):
 
         self.window.quit(shutdown=True)
 
-    def tray_setbwdown(self, widget, data=None):
+    def on_tray_setbwdown(self, widget, data=None):
+        if isinstance(widget, gtk.RadioMenuItem):
+            #ignore previous radiomenuitem value
+            if not widget.get_active():
+                return
         self.setbwlimit(widget, _("Set Maximum Download Speed"), "max_download_speed",
             "tray_download_speed_list", self.max_download_speed, "downloading.svg")
 
+    def on_tray_setbwup(self, widget, data=None):
+        if isinstance(widget, gtk.RadioMenuItem):
+            #ignore previous radiomenuitem value
+            if not widget.get_active():
+                return
+        self.setbwlimit(widget, _("Set Maximum Upload Speed"), "max_upload_speed",
+            "tray_upload_speed_list", self.max_upload_speed, "seeding.svg")
+
     def _on_window_hide(self, widget, data=None):
         """_on_window_hide - update the menuitem's status"""
         log.debug("_on_window_hide")
@@ -413,26 +418,21 @@ class SystemTray(component.Component):
         log.debug("_on_window_show")
         self.tray_glade.get_widget("menuitem_show_deluge").set_active(True)
 
-    def tray_setbwup(self, widget, data=None):
-        self.setbwlimit(widget, _("Set Maximum Upload Speed"), "max_upload_speed",
-            "tray_upload_speed_list", self.max_upload_speed, "seeding.svg")
-
     def setbwlimit(self, widget, string, core_key, ui_key, default, image):
         """Sets the bandwidth limit based on the user selection."""
-        value = widget.get_children()[0].get_text().rstrip(" " + _("KiB/s"))
-        if value == _("Unlimited"):
+        value = widget.get_children()[0].get_text().split(" ")[0]
+        log.debug('setbwlimit: %s', value)
+        if widget.get_name() == "unlimited":
             value = -1
-
-        if value == _("Other..."):
+        if widget.get_name() == "other":
             value = common.show_other_dialog(string, _("KiB/s"), None, image, default)
             if value == None:
                 return
-
+            elif value == 0:
+                value = -1
         # Set the config in the core
         client.core.set_config({core_key: value})
 
-        self.build_tray_bwsetsubmenu()
-
     def unlock_tray(self, is_showing_dlg=[False]):
         try:
             from hashlib import sha1 as sha_hash
@@ -450,13 +450,13 @@ class SystemTray(component.Component):
         entered_pass.set_width_chars(25)
         entered_pass.set_visibility(False)
 
-        tray_lock = gtk.Dialog(title="", parent=self.window.window,
+        self.tray_lock = gtk.Dialog(title="", parent=self.window.window,
             buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL, gtk.STOCK_OK,
             gtk.RESPONSE_OK))
-        tray_lock.set_default_response(gtk.RESPONSE_OK)
-        tray_lock.set_has_separator(False)
+        self.tray_lock.set_default_response(gtk.RESPONSE_OK)
+        self.tray_lock.set_has_separator(False)
 
-        tray_lock.set_border_width(5)
+        self.tray_lock.set_border_width(5)
 
         hbox = gtk.HBox(spacing=5)
 
@@ -467,13 +467,13 @@ class SystemTray(component.Component):
         vbox = gtk.VBox(spacing=5)
         hbox.pack_start(vbox, False)
 
-        label = gtk.Label(_("<b><big>Deluge is password protected!</big></b>"))
+        label = gtk.Label("<b><big>%s</big></b>" % _("Deluge is password protected!"))
         label.set_use_markup(True)
         label.set_alignment(0.0, 0.5)
         label.set_line_wrap(True)
         vbox.pack_start(label, False)
 
-        tlabel = gtk.Label(_("<i>Enter your password to continue</i>"))
+        tlabel = gtk.Label("<i>%s</i>" % _("Enter your password to continue"))
         tlabel.set_use_markup(True)
         tlabel.set_alignment(0.0, 0.5)
         tlabel.set_line_wrap(True)
@@ -481,15 +481,15 @@ class SystemTray(component.Component):
 
         vbox.pack_start(entered_pass)
 
-        tray_lock.vbox.pack_start(hbox)
+        self.tray_lock.vbox.pack_start(hbox)
 
         def on_response(dialog, response_id):
             if response_id == gtk.RESPONSE_OK:
                 if self.config["tray_password"] == sha_hash(entered_pass.get_text()).hexdigest():
                     self.window.present()
 
-            tray_lock.destroy()
+            self.tray_lock.destroy()
             is_showing_dlg[0] = False
 
-        tray_lock.connect("response", on_response)
-        tray_lock.show_all()
+        self.tray_lock.connect("response", on_response)
+        self.tray_lock.show_all()
